@@ -1,17 +1,17 @@
-from arkclient.client import GameBotClient
+from arkclient import GameBotClient
 from time import sleep
 
 
 def test():
-    with GameBotClient("bot") as bot:
+    with GameBotClient(type="bot") as bot:
         for i in range(3):
             response = bot.send('ping')
             sleep(1)
 
-    with GameBotClient("api") as bot:
+    with GameBotClient(type="api") as bot:
         response = bot.send("cheat admin")
 
-    with GameBotClient("bot") as bot:
+    with GameBotClient(type="bot") as bot:
         for i in range(3):
             response = bot.send('ping')
             sleep(1)
